@@ -8,9 +8,6 @@ jpgFile <- system.file(package = 'xROI', 'dukehw.jpg')
 f <- system.file(package = 'xROI', 'dukehw.jpg')
 cli <- getCL(f)
 
-server <- getServer()
-ui <- getUI()
-
 cli_file <- system.file(package = 'xROI', 'dukehw-cli.jpg')
 jp <- jpeg::readJPEG(cli_file)
 
@@ -63,7 +60,3 @@ test_that("test roi", {
   expect_equal(roi$Owner, 'bijan')
 })
 
-test_that("test server ui", {
-  expect_equal(length(server), 1)
-  expect_equal(length(ui), 3)
-})
